@@ -2,7 +2,7 @@ package HTML::SocialMeta::Base;
 use Moo;
 use Carp;
 
-our $VERSION = '0.71';
+our $VERSION = '0.72';
 
 use MooX::LazierAttributes qw/rw ro lzy/;
 use MooX::ValidateSubs;
@@ -12,8 +12,14 @@ attributes(
     [qw(card_type card type name url)] => [ rw, Str, {lzy} ],
     [qw(site fb_app_id site_name title description image creator operatingSystem app_country
     app_name app_id app_url player player_height player_width)] => [ Str, {lzy} ],
+    [qw(image_alt)] => [ Str, {lzy => 1, default => ''} ],
     [qw(card_options build_fields)] => [HashRef,{default => sub { {} }}],
     [qw(meta_attribute meta_namespace)] => [ro],
+    [qw(encoding)] => [HashRef, {lzy, default => sub {
+        my %encode = ( q{&} => q{&amp;}, q{"} => q{&quot;}, q{'} => q{&apos;}, q{<} => q{&lt;}, q{>} => q{&gt;} );
+        $encode{regex} = join "|", keys %encode;
+        return \%encode;
+    }}]
 );
 
 validate_subs(
@@ -63,8 +69,8 @@ sub _validate_field_value {
 
 sub _generate_meta_tag {
 
-    # fields that don't start with app or player generate a single tag
-    $_[1] !~ m{^app|player|fb}xms
+    # fields that don't start with app, player, or image generate a single tag
+    $_[1] !~ m{^app|player|fb|image}xms
       and return $_[0]->_build_field( { field => $_[1] } );
     return
       map { $_[0]->_build_field( { field => $_[1], %{$_} } ) }
@@ -72,10 +78,13 @@ sub _generate_meta_tag {
 }
 
 sub _build_field {
+    my $content = $_[0]->{ $_[1]->{field} };
+    my $encode = $_[0]->encoding; # lazy build  once and not for each field
+    $content =~ s/($encode->{regex})/$encode->{$1}/g;
     return sprintf q{<meta %s="%s:%s" content="%s"/>}, $_[0]->meta_attribute,
       ( $_[1]->{ignore_meta_namespace} // $_[0]->meta_namespace ),
       ( defined $_[1]->{field_type} ? $_[1]->{field_type} : $_[1]->{field} ),
-      $_[0]->{ $_[1]->{field} };
+      $content;
 }
 
 sub _convert_field {
@@ -112,26 +121,27 @@ builds and returns the Meta Tags
 
 =head1 VERSION
 
-Version 0.71
+Version 0.72
 
 =cut
 
 =head1 SYNOPSIS
 
     use HTML::SocialMeta;
-    # summary or featured image 
+    # summary or featured image
     my $social = HTML::SocialMeta->new(
         site => '',
         site_name => '',
         title => '',
         description => '',
         image   => '',
+        image_alt => '',
         url  => '',  # optional
         ... => '',
         ... => '',
     );
 
-    # returns meta tags for all providers   
+    # returns meta tags for all providers
     # 'summary', 'featured_image', 'app', 'player'
     my $meta_tags = $social->create('summary');
 
