@@ -5,7 +5,7 @@ use Carp;
 
 extends 'HTML::SocialMeta::Base';
 
-our $VERSION = '0.71';
+our $VERSION = '0.72';
 
 use MooX::LazierAttributes;
 use MooX::ValidateSubs;
@@ -27,13 +27,13 @@ attributes(
     '+build_fields' => [
         sub {
             {
-                summary             => [qw(card site title description image)],
-                summary_large_image => [qw(card site title description image)],
+                summary             => [qw(card site title description image image_alt)],
+                summary_large_image => [qw(card site title description image image_alt)],
                 app                 => [
                     qw(card site description app_country app_name app_id app_url)
                 ],
                 player => [
-                    qw(card site title description image player player_width player_height)
+                    qw(card site title description image image_alt player player_width player_height)
                 ],
             };
         }
@@ -102,7 +102,7 @@ HTML::SocialMeta::Twitter
 
 =head1 VERSION
 
-Version 0.71
+Version 0.72
 
 =cut
 
